package com.puppycrawl.tools.checkstyle.checks.imports.customimportorder; import static java.awt.Button.ABORT; import java.util.Map; import java.util.Map.Entry;
import com.google.common.annotations.Beta; import com.google.common.collect.HashMultimap;

import org.junit.rules.*;
import org.junit.runner.*;
import org.junit.validator.*;


import com.puppycrawl.tools.checkstyle.*;



import antlr.*;

class InputCustomImportOrderSingleLine {}
